@@ -3,6 +3,7 @@
  *
  * SPDX-FileCopyrightText: 2000-2003 Hans Petter Bieker <bieker@kde.org>
  * SPDX-FileCopyrightText: 2009 George Kiagiadakis <gkiagia@users.sourceforge.net>
+ * SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
  *
  * SPDX-License-Identifier: BSD-2-Clause
  *****************************************************************/
@@ -17,9 +18,6 @@
 BacktraceGenerator::BacktraceGenerator(const Debugger &debugger, QObject *parent)
     : QObject(parent)
     , m_debugger(debugger)
-    , m_proc(nullptr)
-    , m_temp(nullptr)
-    , m_state(NotLoaded)
 {
     m_parser = BacktraceParser::newParser(m_debugger.codeName(), this);
     m_parser->connectToGenerator(this);
@@ -48,24 +46,127 @@ BacktraceGenerator::~BacktraceGenerator()
     }
 }
 
-bool BacktraceGenerator::start()
+void BacktraceGenerator::start()
 {
     // they should always be null before entering this function.
     Q_ASSERT(!m_proc);
     Q_ASSERT(!m_temp);
 
     m_parsedBacktrace.clear();
-    m_state = Loading;
-
-    emit starting();
 
     if (!m_debugger.isValid() || !m_debugger.isInstalled()) {
         qCWarning(DRKONQI_LOG) << "Debugger valid" << m_debugger.isValid() << "installed" << m_debugger.isInstalled();
         m_state = FailedToStart;
-        emit failedToStart();
-        return false;
+        Q_EMIT failedToStart();
+        return;
     }
 
+    m_state = Loading;
+    Q_EMIT preparing();
+    // DebuggerManager calls setBackendPrepared when it is ready for us to actually start.
+}
+
+void BacktraceGenerator::slotReadInput()
+{
+    if (!m_proc) {
+        // this can happen with lldb after we detected that it detached from the debuggee.
+        return;
+    }
+
+    // we do not know if the output array ends in the middle of an utf-8 sequence
+    m_output += m_proc->readAllStandardOutput();
+
+    int pos;
+    while ((pos = m_output.indexOf('\n')) != -1) {
+        QString line = QString::fromLocal8Bit(m_output.constData(), pos + 1);
+        m_output.remove(0, pos + 1);
+
+        Q_EMIT newLine(line);
+        line = line.simplified();
+        if (line.startsWith(QLatin1String("Process ")) && line.endsWith(QLatin1String(" detached"))) {
+            // lldb is acting on a detach command (in lldbrc)
+            // Anything following this line doesn't interest us, and lldb has been known
+            // to turn into a zombie instead of exiting, thereby blocking us.
+            // Tell the process to quit if it's still running, and pretend it did.
+            if (m_proc && m_proc->state() == QProcess::Running) {
+                m_proc->terminate();
+                if (!m_proc->waitForFinished(500)) {
+                    m_proc->kill();
+                }
+                if (m_proc) {
+                    slotProcessExited(0, QProcess::NormalExit);
+                }
+            }
+            return;
+        }
+    }
+}
+
+void BacktraceGenerator::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
+{
+    // these are useless now
+    m_proc->deleteLater();
+    m_temp->deleteLater();
+    m_proc = nullptr;
+    m_temp = nullptr;
+
+    // mark the end of the backtrace for the parser
+    Q_EMIT newLine(QString());
+
+    if (exitStatus != QProcess::NormalExit || exitCode != 0) {
+        m_state = Failed;
+        Q_EMIT someError();
+        return;
+    }
+
+    // no translation, string appears in the report
+    QString tmp(QStringLiteral("Application: %progname (%execname), signal: %signame\n"));
+    Debugger::expandString(tmp);
+
+    m_parsedBacktrace = tmp + m_parser->informationLines() + m_parser->parsedBacktrace();
+    m_state = Loaded;
+
+#ifdef BACKTRACE_PARSER_DEBUG
+    // append the raw unparsed backtrace
+    m_parsedBacktrace += "\n------------ Unparsed Backtrace ------------\n";
+    m_parsedBacktrace += m_debugParser->parsedBacktrace(); // it's not really parsed, it's from the null parser.
+#endif
+
+    Q_EMIT done();
+}
+
+void BacktraceGenerator::slotOnErrorOccurred(QProcess::ProcessError error)
+{
+    qCWarning(DRKONQI_LOG) << "Debugger process had an error" << error << m_proc->program() << m_proc->arguments() << m_proc->environment();
+
+    // we mustn't keep these around...
+    m_proc->deleteLater();
+    m_temp->deleteLater();
+    m_proc = nullptr;
+    m_temp = nullptr;
+
+    switch (error) {
+    case QProcess::FailedToStart:
+        m_state = FailedToStart;
+        Q_EMIT failedToStart();
+        break;
+    default:
+        m_state = Failed;
+        Q_EMIT someError();
+        break;
+    }
+}
+
+void BacktraceGenerator::setBackendPrepared()
+{
+    // they should always be null before entering this function.
+    Q_ASSERT(!m_proc);
+    Q_ASSERT(!m_temp);
+
+    Q_ASSERT(m_state == Loading);
+
+    Q_EMIT starting();
+
     m_proc = new KProcess;
     m_proc->setEnv(QStringLiteral("LC_ALL"), QStringLiteral("C")); // force C locale
 
@@ -97,90 +198,7 @@ bool BacktraceGenerator::start()
     }
     connect(m_proc, &KProcess::readyReadStandardOutput, this, &BacktraceGenerator::slotReadInput);
     connect(m_proc, static_cast<void (KProcess::*)(int, QProcess::ExitStatus)>(&KProcess::finished), this, &BacktraceGenerator::slotProcessExited);
+    connect(m_proc, &KProcess::errorOccurred, this, &BacktraceGenerator::slotOnErrorOccurred);
 
     m_proc->start();
-    if (!m_proc->waitForStarted()) {
-        qCWarning(DRKONQI_LOG) << "Debugger process failed to start" << m_proc->program() << m_proc->arguments() << m_proc->environment();
-
-        // we mustn't keep these around...
-        m_proc->deleteLater();
-        m_temp->deleteLater();
-        m_proc = nullptr;
-        m_temp = nullptr;
-
-        m_state = FailedToStart;
-        emit failedToStart();
-        return false;
-    }
-
-    return true;
-}
-
-void BacktraceGenerator::slotReadInput()
-{
-    if (!m_proc) {
-        // this can happen with lldb after we detected that it detached from the debuggee.
-        return;
-    }
-
-    // we do not know if the output array ends in the middle of an utf-8 sequence
-    m_output += m_proc->readAllStandardOutput();
-
-    int pos;
-    while ((pos = m_output.indexOf('\n')) != -1) {
-        QString line = QString::fromLocal8Bit(m_output.constData(), pos + 1);
-        m_output.remove(0, pos + 1);
-
-        emit newLine(line);
-        line = line.simplified();
-        if (line.startsWith(QLatin1String("Process ")) && line.endsWith(QLatin1String(" detached"))) {
-            // lldb is acting on a detach command (in lldbrc)
-            // Anything following this line doesn't interest us, and lldb has been known
-            // to turn into a zombie instead of exiting, thereby blocking us.
-            // Tell the process to quit if it's still running, and pretend it did.
-            if (m_proc && m_proc->state() == QProcess::Running) {
-                m_proc->terminate();
-                if (!m_proc->waitForFinished(500)) {
-                    m_proc->kill();
-                }
-                if (m_proc) {
-                    slotProcessExited(0, QProcess::NormalExit);
-                }
-            }
-            return;
-        }
-    }
-}
-
-void BacktraceGenerator::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
-{
-    // these are useless now
-    m_proc->deleteLater();
-    m_temp->deleteLater();
-    m_proc = nullptr;
-    m_temp = nullptr;
-
-    // mark the end of the backtrace for the parser
-    emit newLine(QString());
-
-    if (exitStatus != QProcess::NormalExit || exitCode != 0) {
-        m_state = Failed;
-        emit someError();
-        return;
-    }
-
-    // no translation, string appears in the report
-    QString tmp(QStringLiteral("Application: %progname (%execname), signal: %signame\n"));
-    Debugger::expandString(tmp);
-
-    m_parsedBacktrace = tmp + m_parser->informationLines() + m_parser->parsedBacktrace();
-    m_state = Loaded;
-
-#ifdef BACKTRACE_PARSER_DEBUG
-    // append the raw unparsed backtrace
-    m_parsedBacktrace += "\n------------ Unparsed Backtrace ------------\n";
-    m_parsedBacktrace += m_debugParser->parsedBacktrace(); // it's not really parsed, it's from the null parser.
-#endif
-
-    emit done();
 }
