@@ -2,6 +2,7 @@
  * drkonqi - The KDE Crash Handler
  *
  * SPDX-FileCopyrightText: 2000-2003 Hans Petter Bieker <bieker@kde.org>
+ * SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
  *
  * SPDX-License-Identifier: BSD-2-Clause
  *****************************************************************/
@@ -53,8 +54,11 @@ public:
         return m_debugger;
     }
 
+    // Called by manager when it is ready for us.
+    void setBackendPrepared();
+
 public Q_SLOTS:
-    bool start();
+    void start();
 
 Q_SIGNALS:
     void starting();
@@ -62,17 +66,19 @@ Q_SIGNALS:
     void someError();
     void failedToStart();
     void done();
+    void preparing();
 
 private Q_SLOTS:
     void slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus);
     void slotReadInput();
+    void slotOnErrorOccurred(QProcess::ProcessError error);
 
 private:
     const Debugger m_debugger;
     KProcess *m_proc = nullptr;
     QTemporaryFile *m_temp = nullptr;
     QByteArray m_output;
-    State m_state;
+    State m_state = NotLoaded;
     BacktraceParser *m_parser = nullptr;
     QString m_parsedBacktrace;
 
