@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2019-2021 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -10,6 +10,7 @@
 #include <QMetaObject>
 #include <QMetaType>
 #include <QSharedPointer>
+
 namespace Bugzilla
 {
 Product::Ptr ProductClient::get(KJob *kjob)
@@ -17,6 +18,9 @@ Product::Ptr ProductClient::get(KJob *kjob)
     auto job = qobject_cast<APIJob *>(kjob);
 
     const QJsonArray productsArray = job->object().value(QLatin1String("products")).toArray();
+    if (productsArray.isEmpty()) {
+        throw Bugzilla::RuntimeException(QStringLiteral("Failed to resolve bugzilla product"));
+    }
     Q_ASSERT(productsArray.size() == 1);
 
     auto obj = productsArray.at(0).toObject().toVariantHash();
