@@ -35,10 +35,21 @@ public:
 
     void setAboutToSend(bool aboutTo);
 
+    // DO NOT CALL THIS FUNCTION. isAppropriate from KAssistantDialog is
+    // not suitable for our dialog. Use the page's individual isAppropriate()
+    // to check whether the specific page is appropriate.
+    // You can also use isItemAppropriate if you only have an item.
+    bool isAppropriate(KPageWidgetItem *page) const = delete;
+
+    // Use this function instead of isAppropriate()
+    bool isItemAppropriate(KPageWidgetItem *item) const;
+
 public Q_SLOTS:
     void next() override;
     void back() override;
 
+    void assistantFinished(bool);
+
 private Q_SLOTS:
     void currentPageChanged_slot(KPageWidgetItem *, KPageWidgetItem *);
 
@@ -46,8 +57,6 @@ private Q_SLOTS:
 
     void loginFinished();
 
-    void assistantFinished(bool);
-
     void showHelp();
 
     // Override default reject method
@@ -56,8 +65,7 @@ private Q_SLOTS:
 private:
     void connectSignals(ReportAssistantPage *);
     void closeEvent(QCloseEvent *) override;
-
-    QHash<QLatin1String, KPageWidgetItem *> m_pageWidgetMap;
+    void skipInappropriatePage();
 
     QPointer<AboutBugReportingDialog> m_aboutBugReportingDialog;
     ReportInterface *m_reportInterface = nullptr;
@@ -68,6 +76,10 @@ private:
     QString m_nextButtonTextCache;
     // Page sequence.
     std::vector<KPageWidgetItem *> m_pageItems;
+
+    // Track current movement direction. When going next()/back() we want to auto-skip inappropriate pages on-the-fly.
+    enum class Movement { Unknown, Forward, Backward };
+    Movement m_move = Movement::Unknown;
 };
 
 #endif
