@@ -20,17 +20,40 @@
 #endif
 #endif
 
-#include <KToolInvocation>
+#include <KIO/CommandLauncherJob>
+
+CrashedApplication::CrashedApplication(int pid,
+                                       int thread,
+                                       int signalNumber,
+                                       const QFileInfo &executable,
+                                       const QString &version,
+                                       const BugReportAddress &reportAddress,
+                                       const QString &name,
+                                       const QString &productName,
+                                       const QDateTime &datetime,
+                                       bool restarted,
+                                       bool hasDeletedFiles,
+                                       const QString &fakeBaseName,
+                                       QObject *parent)
 
-CrashedApplication::CrashedApplication(QObject *parent)
     : QObject(parent)
-    , m_restarted(false)
+    , m_pid(pid)
+    , m_signalNumber(signalNumber)
+    , m_name(name)
+    , m_executable(executable)
+    , m_fakeBaseName(fakeBaseName)
+    , m_version(version)
+    , m_reportAddress(reportAddress)
+    , m_productName(productName)
+    , m_restarted(restarted)
+    , m_thread(thread)
+    , m_datetime(datetime)
+    , m_hasDeletedFiles(hasDeletedFiles)
+
 {
 }
 
-CrashedApplication::~CrashedApplication()
-{
-}
+CrashedApplication::~CrashedApplication() = default;
 
 QString CrashedApplication::name() const
 {
@@ -61,6 +84,11 @@ BugReportAddress CrashedApplication::bugReportAddress() const
     return m_reportAddress;
 }
 
+QString CrashedApplication::productName() const
+{
+    return m_productName;
+}
+
 int CrashedApplication::pid() const
 {
     return m_pid;
@@ -74,17 +102,10 @@ int CrashedApplication::signalNumber() const
 QString CrashedApplication::signalName() const
 {
 #if HAVE_STRSIGNAL && defined(Q_OS_UNIX)
-    const char *oldLocale = std::setlocale(LC_MESSAGES, nullptr);
-    char *savedLocale;
-    if (oldLocale) {
-        savedLocale = strdup(oldLocale);
-    } else {
-        savedLocale = nullptr;
-    }
+    const QByteArray originalLocale(std::setlocale(LC_MESSAGES, nullptr));
     std::setlocale(LC_MESSAGES, "C");
     const char *name = strsignal(m_signalNumber);
-    std::setlocale(LC_MESSAGES, savedLocale);
-    std::free(savedLocale);
+    std::setlocale(LC_MESSAGES, originalLocale.data() /* empty string if we got a nullptr */);
     return QString::fromLocal8Bit(name ? name : "Unknown");
 #else
     switch (m_signalNumber) {
@@ -173,15 +194,18 @@ void CrashedApplication::restart()
         return;
     }
 
-    // start the application via kdeinit, as it needs to have a pristine environment and
-    // KProcess::startDetached() can't start a new process with custom environment variables.
+    // start the application via CommandLauncherJob so it runs in a new cgroup if possible.
     // if m_fakeBaseName is set, this means m_executable is the path to kdeinit4
     // so we need to use the fakeBaseName to restart the app
-    const int ret = KToolInvocation::kdeinitExec(!m_fakeBaseName.isEmpty() ? m_fakeBaseName : m_executable.absoluteFilePath());
-    const bool success = (ret == 0);
-
-    m_restarted = success;
-    emit restarted(success);
+    auto job = new KIO::CommandLauncherJob(!m_fakeBaseName.isEmpty() ? m_fakeBaseName : m_executable.absoluteFilePath());
+    if (const QString &id = DrKonqi::startupId(); !id.isEmpty()) {
+        job->setStartupId(id.toUtf8());
+    }
+    connect(job, &KIO::CommandLauncherJob::result, this, [job, this] {
+        m_restarted = (job->error() == KJob::NoError);
+        Q_EMIT restarted(m_restarted);
+    });
+    job->start();
 }
 
 QString getSuggestedKCrashFilename(const CrashedApplication *app)
