@@ -6,11 +6,14 @@
 #include "detachedprocessmonitor.h"
 #include "drkonqi_debug.h"
 
+#include <chrono>
 #include <errno.h>
 #include <signal.h>
 
 #include <QTimerEvent>
 
+using namespace std::chrono_literals;
+
 DetachedProcessMonitor::DetachedProcessMonitor(QObject *parent)
     : QObject(parent)
     , m_pid(0)
@@ -20,7 +23,7 @@ DetachedProcessMonitor::DetachedProcessMonitor(QObject *parent)
 void DetachedProcessMonitor::startMonitoring(int pid)
 {
     m_pid = pid;
-    startTimer(10);
+    startTimer(10ms);
 }
 
 void DetachedProcessMonitor::timerEvent(QTimerEvent *event)
@@ -30,6 +33,6 @@ void DetachedProcessMonitor::timerEvent(QTimerEvent *event)
         qCDebug(DRKONQI_LOG) << "Process" << m_pid << "finished. kill(2) returned errno:" << errno;
         killTimer(event->timerId());
         m_pid = 0;
-        emit processFinished();
+        Q_EMIT processFinished();
     }
 }
